import express from 'express';
import config, { fetchAssistantSettings, updateCachedSettings } from './config/appConfig';

const router = express.Router();

router.post('/', async (req, res) => {
  console.log('Webhook request received:', req.body);
  const authHeader = req.headers.authorization;
  if (!authHeader || !authHeader.startsWith('Bearer ')) {
    console.log('Webhook request received without proper authorization');
    return res.status(401).json({ error: 'Unauthorized' });
  }

  const token = authHeader.split(' ')[1];
  if (token !== config.voice360ApiKey) {
    console.log('Webhook request received with invalid API key');
    return res.status(401).json({ error: 'Invalid API key' });
  }

  try {
    const newSettings = await fetchAssistantSettings(config.assistantId);
    updateCachedSettings(newSettings);
    console.log('Cache updated successfully via webhook');
    res.json({ message: 'Cache updated successfully' });
  } catch (error) {
    console.error('Error updating cache via webhook', error);
    res.status(500).json({ error: 'Failed to update cache' });
  }
});

// Test endpoint
router.get('/test', (req, res) => {
  console.log('Test webhook endpoint hit');
  res.json({ message: 'Webhook is working' });
});

export default router;
